from typing import Dict

HEADER_STYLES: Dict[str, Dict] = {
    "container": {
        "padding": "0px",
        "display": "grid",
        "margin": "0!important",
        "background-color": "#2C3333"
    },
    "icon": {"color": "#CBE4DE", "font-size": "14px"},
    "nav-link": {
        "font-size": "14px",
        "text-align": "center",
        "margin": "auto",
        "background-color": "#2C3333",
        "height": "30px",
        "width": "7rem",
        "color": "#CBE4DE",
        "border-radius": "5px"
    },
    "nav-link-selected": {
        "background-color": "#2E4F4F",
        "font-weight": "300",
        "color": "#f5f5f5",
        "border": "1px solid #0E8388"
    }
}

FOOTER_STYLES: Dict[str, Dict] = {

}
